@@ -4,6 +4,7 @@
 #'
 #' @param Urls A character vector of the memento of the Internet Archive
 #' @param Paths A named character vector of the content to be scraped from the memento. Takes XPath expressions as default.
+#' @param collapse Collapse matching html nodes
 #' @param startnum Specify the starting number for scraping the Urls. Important when scraping breaks during process.
 #' @param attachto Scraper attaches new content to existing object in working memory. Object should stem from same scraping process.
 #' @param CSS Use CSS selectors as input for the Paths
@@ -33,9 +34,12 @@
 
 ### Function --------------------
 
+
+
 scrape_urls <-
   function(Urls,
            Paths,
+           collapse = TRUE,
            startnum = 1,
            attachto = NULL,
            CSS = FALSE,
@@ -45,7 +49,10 @@ scrape_urls <-
            emptylim = 10,
            encoding = "UTF-8",
            lengthwarning = TRUE) {
-    #### A priori consistency checks
+
+
+  #### A priori consistency checks
+
     # Globally bind variables
     counter <- NULL
 
@@ -65,6 +72,12 @@ scrape_urls <-
         "Paths is not a character vector. Please provide a named character vector of Xpath or CSS paths."
       )
 
+
+    # collapse must be logical
+    if (!is.logical(collapse))
+      stop ("collapse is not a logical value. Please provide TRUE or FALSE.")
+
+
     # startnum must be a single numerical value in the range of the length of Urls
     if (!is.numeric(startnum))
       stop (
@@ -81,21 +94,14 @@ scrape_urls <-
         "startnum value exceeds number of Urls given. Please provide a numeric indicating at which Url you want to start the scraping process."
       )
 
-    # attachto must stem from the same scraping process
+
+    # attachto must stem from same scraping process
     if (!is.null(attachto))
       if (setequal(colnames(attachto),
-                   c("Urls", names(Paths), "progress")
-                   ) == F)
+                   c("Urls", names(Paths), "stoppedat")
+      ) == FALSE)
         stop ("attachto must be a failed output of this function.")
 
-    checkAttachtoUrl <- attachto$Urls[1]
-    checkUrl <- Urls[1]
-
-    if (!is.null(attachto))
-      if (checkAttachtoUrl != checkUrl)
-        stop (
-          "Input Urls and Urls in attachto file differ. Please note that the attachto file can only be used for attaching failed output from the same function and scraping process."
-        )
 
     # CSS must be logical
     if (!is.logical(CSS))
@@ -105,7 +111,6 @@ scrape_urls <-
       stop ("CSS is not a single value. Please provide TRUE or FALSE.")
 
     # archiveDate must be logical
-
     if (!is.logical(archiveDate))
       stop ("archiveDate is not a logical value. Please provide TRUE or FALSE.")
 
@@ -159,155 +164,192 @@ scrape_urls <-
     }
 
 
-    #### Main function
-
-    # Generate list for output
-    scrapedUrls <- vector(mode = "list", length = length(Urls))
-
-
-    #Progress bar
-    pb <- txtProgressBar(min = 0,
-                         max = length(Urls),
-                         style = 3)
 
 
 
-    # Start if attachto is used
-    if (!is.null(attachto)) {
-      scrapedUrls <-
-        split(attachto[1:sum(attachto$progress), 2:(ncol(attachto) - 1)], seq(1:sum(attachto$progress)))
-      length(scrapedUrls) <- length(Urls)
-    }
 
 
-    if (startnum > 1) {
-      for (i in seq_len(startnum - 1)) {
-        if (is.null(scrapedUrls[[i]])) {
-          scrapedUrls[[i]] <-
-            as.data.frame(matrix(ncol = length(Paths), nrow = 1))
 
-          cnames <- seq(1:length(Paths))
-          cnames <- paste0("Xpath", cnames)
-          cnames[names(Paths) != ""] <- names(Paths)[names(Paths) != ""]
 
-          colnames(scrapedUrls[[i]]) <- cnames
-        }
+
+
+
+
+#### Main function
+
+# Generate list for output
+scrapedUrls <- vector(mode = "list", length = length(Urls))
+
+# Generate counter for later use
+counter <- 0
+
+
+#Progress bar
+if(length(Urls) > 1){
+  pb <- txtProgressBar(min = 0,
+                       max = length(Urls),
+                       style = 3)
+}
+
+
+for (i in (seq_len(length(Urls)-(startnum-1))+(startnum-1))) {
+
+  # Sys.sleep
+  if ((i > startnum) & ((i - startnum) %% 20 == 0)) {
+    Sys.sleep(abs(rnorm(1, 5, 2)))
+  }
+
+  # Set up List
+  data <- list()
+
+  # Avoid Urls that cannot be retrieved
+  possibleError <- tryCatch(
+    r <- httr::GET(Urls[i], httr::timeout(20)),
+    error = function(e)
+      e
+  )
+
+  # Skip if error
+  if (inherits(possibleError, "error")) {
+    # Fill data
+    data <- as.data.frame(matrix(ncol = length(Paths), nrow = 1))
+
+    # Name columns
+    cnames <- seq_len(length(Paths))
+    cnames <- paste0("Xpath", cnames)
+    cnames[names(Paths) != ""] <- names(Paths)[names(Paths) != ""]
+
+    colnames(data) <- cnames
+
+    # Fill in scrapedUrls List and add Url information
+    scrapedUrls[[i]] <- cbind(Urls[[i]], data)
+    colnames(scrapedUrls[[i]])[1] <- "Urls"
+    next
+  }
+
+  # Get httr status
+  status <- httr::status_code(r)
+
+  # Retrieve if status = 200
+  if (status == 200) {
+
+    tryCatch({
+    html <- xml2::read_html(r, encoding = encoding)
+
+    # Retrieve elements and store in data list
+    if (CSS == T) {
+      # Extract nodes
+      for (x in seq_len(length(Paths))) {
+        data[[x]] <- rvest::html_nodes(html, css = Paths[x])
+        data[[x]] <- rvest::html_text(data[[x]])
+      }
+    } else {
+      # Extract nodes
+      for (x in seq_len(length(Paths))) {
+        data[[x]] <- rvest::html_nodes(html, xpath = Paths[x])
+        data[[x]] <- rvest::html_text(data[[x]])
       }
     }
 
-
-    # Loop over all Urls
-    for (i in (seq_len(length(Urls)-(startnum-1))+(startnum-1))) {
-      # Sys.sleep
-      if ((i > startnum) & ((i - startnum) %% 20 == 0)) {
-        Sys.sleep(abs(rnorm(1, 5, 2)))
+    # If collapse = TRUE, collapse retrieved html elements
+    if (collapse == TRUE) {
+      for (x in seq_len(length(Paths))) {
+        data[[x]] <- paste(data[[x]], collapse = ' ')
       }
+    }
+
+  # End trycatch
+  },
+  error = function(e) {
+    cat("ERROR :", conditionMessage(e), "\n")
+  })
+
+  # End status == 200 if clause
+  } else {
+    # Fill data
+    data <- as.data.frame(matrix(ncol = length(Paths), nrow = 1))
+
+    # Name columns
+    cnames <- seq_len(length(Paths))
+    cnames <- paste0("Xpath", cnames)
+    cnames[names(Paths) != ""] <- names(Paths)[names(Paths) != ""]
+
+    colnames(data) <- cnames
+  }
 
 
+  # Stops
 
-      # Avoid Urls that cannot be retrieved
-      possibleError <- tryCatch(
-        r <- httr::GET(Urls[i], httr::timeout(20)),
-        error = function(e)
-          e
+    # If collapse = FALSE, stop if lengths of retrived elements differs
+    if (collapse == FALSE & length(unique(sapply(data, length)))!=1 & ignoreErrors == FALSE) {
+
+      # Preliminary output
+      predata <- do.call("rbind", scrapedUrls)
+
+      output <- tibble::tibble(predata, stoppedat = i)
+
+      warning(
+        paste0(
+          "Error in scraping of Url ",
+          i,
+          " '",
+          Urls[i],
+          "'. Number of elements for paths differs. Please provide paths that result in a similar number of elements per Url or use the option collapse = TRUE. A preliminary output has been printed."
+        )
       )
+      return(output)
+    }
 
 
-      if (inherits(possibleError, "error")) {
-        scrapedUrls[[i]] <-
-          as.data.frame(matrix(ncol = length(Paths), nrow = 1))
+    # Stop if too many empty outputs in a row
 
-        cnames <- seq_len(length(Paths))
-        cnames <- paste0("Xpath", cnames)
-        cnames[names(Paths) != ""] <- names(Paths)[names(Paths) != ""]
+    # Counter for empty outputs in a row
+    if(collapse == F){
 
-        colnames(scrapedUrls[[i]]) <- cnames
-        next
+      if (sum(sapply(sapply(data, stringr::str_length), sum) == 0) == length(Paths)){
+        counter <-  counter + 1
+      } else {
+        counter <- 0
       }
+    } else {
 
-      status <- httr::status_code(r)
-      if (status == 200) {
-        # Scrape page, using rvest
-        tryCatch({
-          html <- xml2::read_html(r, encoding = encoding)
-
-
-          data <- list()
-
-          if (CSS == T) {
-            # Extract nodes
-            for (x in seq_len(length(Paths))) {
-              data[[x]] <- rvest::html_nodes(html, css = Paths[x])
-              data[[x]] <- rvest::html_text(data[[x]])
-              data[[x]] <- paste(data[[x]], collapse = ' ')
-            }
-          } else {
-            # Extract nodes
-            for (x in seq_len(length(Paths))) {
-              data[[x]] <- rvest::html_nodes(html, xpath = Paths[x])
-              data[[x]] <- rvest::html_text(data[[x]])
-              data[[x]] <- paste(data[[x]], collapse = ' ')
-            }
-          }
-
-          data <- as.data.frame(data)
-
-          cnames <- seq_len(length(Paths))
-          cnames <- paste0("Xpath", cnames)
-          cnames[names(Paths) != ""] <- names(Paths)[names(Paths) != ""]
-
-          colnames(data) <- cnames
-
-
-
-          scrapedUrls[[i]] <- data
-
-
-          # Counter for empty outputs in a row
-          if (i == 1) {
-            counter <- 0
-          }
-          if (sum(stringr::str_length(data) == 0) == ncol(data)) {
-            counter <-  counter + 1
-          } else {
-            counter <- 0
-          }
-
-
-
-        },
-        error = function(e) {
-          cat("ERROR :", conditionMessage(e), "\n")
-        })
+      if (sum(stringr::str_length(data) == 0) == length(Paths)){
+        counter <-  counter + 1
+      } else {
+        counter <- 0
       }
+    }
 
 
-      if (is.null(scrapedUrls[[i]])) {
-        scrapedUrls[[i]] <-
-          as.data.frame(matrix(ncol = length(Paths), nrow = 1))
+    if (counter >= emptylim &
+        stopatempty == TRUE & ignoreErrors == FALSE) {
 
-        cnames <- seq_len(length(Paths))
-        cnames <- paste0("Xpath", cnames)
-        cnames[names(Paths) != ""] <- names(Paths)[names(Paths) != ""]
+      # Preliminary output
+      predata <- do.call("rbind", scrapedUrls)
 
-        colnames(scrapedUrls[[i]]) <- cnames
+      output <- tibble::tibble(predata, stoppedat = i)
 
-      }
+      warning(
+        paste0(
+          "Error in scraping of Url ",
+          i,
+          " '",
+          Urls[i],
+          "'. Too many empty outputs in a row. A preliminary output has been printed."
+        )
+      )
+      return(output)
+    }
 
 
+    # Stop if non-matching number of paths could be extracted
+    if (collapse == F){
+      if (any(sapply(sapply(data, stringr::str_length), length)==0) & ignoreErrors == FALSE) {
 
-      # Stop if non-matching number of paths could be extracted
-      if ((sum(stringr::str_length(scrapedUrls[[i]][seq_len(length(Paths))]) == 0) != 0) &
-          (sum(stringr::str_length(scrapedUrls[[i]][seq_len(length(Paths))]) == 0) != length(Paths)) &
-          (ignoreErrors == F)) {
         # Preliminary output
-
         predata <- do.call("rbind", scrapedUrls)
 
-        Urls <- Urls[seq_len(nrow(predata))]
-
-        output <- tibble::tibble(Urls, predata, progress = 0)
-        output$progress[0:(i - 1)] <- 1
+        output <- tibble::tibble(predata, stoppedat = i)
 
         warning(
           paste0(
@@ -319,20 +361,15 @@ scrape_urls <-
           )
         )
         return(output)
+
       }
+    } else {
+      if (length(unique(sapply(data, stringr::str_length)==0))!=1 & ignoreErrors == FALSE) {
 
-
-      # Stop if too many empty outputs in a row
-      if (counter >= emptylim &
-          stopatempty == T & ignoreErrors == F) {
         # Preliminary output
-
         predata <- do.call("rbind", scrapedUrls)
 
-        Urls <- Urls[seq_len(nrow(predata))]
-
-        output <- tibble::tibble(Urls, predata, progress = 0)
-        output$progress[0:(i - emptylim)] <- 1
+        output <- tibble::tibble(predata, stoppedat = i)
 
         warning(
           paste0(
@@ -340,34 +377,70 @@ scrape_urls <-
             i,
             " '",
             Urls[i],
-            "'. Too many empty outputs in a row. A preliminary output has been printed."
+            "'. Only some of your Paths could be extracted. A preliminary output has been printed."
           )
         )
         return(output)
+
       }
+    }
 
-      # Progress message
+
+
+  # Data as dataframe
+
+    # List as dataframe
+    if (collapse == F){
+      data <- as.data.frame(sapply(data, '[', seq(max(sapply(data, length)))))
+    } else {
+      data <- as.data.frame(data)
+    }
+
+
+    # Add column names
+    cnames <- seq_len(length(Paths))
+    cnames <- paste0("Xpath", cnames)
+    cnames[names(Paths) != ""] <- names(Paths)[names(Paths) != ""]
+
+    colnames(data) <- cnames
+
+
+    # Add Url as row and save in List over all Urls
+    scrapedUrls[[i]] <- cbind(Urls[[i]], data)
+    colnames(scrapedUrls[[i]])[1] <- "Urls"
+
+
+    # Progress message
+    if(length(Urls) > 1){
       setTxtProgressBar(pb, i)
-
     }
 
-    # Generate output dataframe
+} # End for loop
 
-    output <- do.call("rbind", scrapedUrls)
+  # Generate output dataframe
+  output <- do.call("rbind", scrapedUrls)
 
-    Urls <- Urls[seq_len(nrow(output))]
-    output <- tibble::tibble(Urls, output)
-
-    if (archiveDate == T) {
-      output$archiveDate <-
-        anytime::anydate(
-          stringr::str_extract(
-            output$Urls,
-            "(?<=\\:\\/\\/web\\.archive\\.org\\/web\\/)[0-9]{8}"
-          )
-        )
-    }
-
-    #### Return output
-    return(output)
+  # Attach attachto to retrived data
+  if (!is.null(attachto)) {
+    output <- rbind(attachto[,-grep("stoppedat", colnames(attachto))], output)
   }
+
+  # If archiveDate = TRUE, add information
+  if (archiveDate == TRUE) {
+    output$archiveDate <-
+      anytime::anydate(
+        stringr::str_extract(
+          output$Urls,
+          "(?<=\\:\\/\\/web\\.archive\\.org\\/web\\/)[0-9]{8}"
+        )
+      )
+  }
+
+  # Output as tibble
+  output <- tibble::tibble(output)
+
+  #### Return output
+  return(output)
+
+}
+
