@@ -3,8 +3,11 @@ library(testthat)
 library(webmockr)
 library(archiveRetriever)
 
+#Several tests are skipped_on_cran as it is always possible that the Internet Archive might be inaccessible at times. The tests do run successfully on our machines.
+
 #Check for the sensitivity of the date format
 test_that("archive_overview() returns a plot with the correct time frame", {
+  skip_on_cran()
   output_overview <-
     archive_overview(homepage = "https://www.nytimes.com/",
                      startDate = "2018-06-01",
@@ -15,6 +18,7 @@ test_that("archive_overview() returns a plot with the correct time frame", {
 
 #Check for correct output when covering more than one year
 test_that("archive_overview() returns a plot in gtable class", {
+  skip_on_cran()
   output_overview <-
     archive_overview(homepage = "https://www.nytimes.com/",
                      startDate = "2018-06-01",
@@ -69,6 +73,7 @@ test_that("archive_overview() needs endDate to be not in the future", {
 #Check whether Homepage has ever been saved in the Internet Archive
 test_that("archive_overview() needs homepage to be saved in the Internet Archive",
           {
+            skip_on_cran()
             expect_error(
               archive_overview(
                 "https://cyprus-mail.com/2021/02/18/the-secret-helping-car-companies-stay-profitable/",
